==> apache-eventmesh-1.10.0-source.tar.gz: apache-eventmesh-1.10.0-src/eventmesh-trace-plugin/eventmesh-trace-api/src/main/java/org/apache/eventmesh/trace/api/config/ExporterConfiguration.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.eventmesh.trace.api.config;

import org.apache.eventmesh.common.config.Config;
import org.apache.eventmesh.common.config.ConfigFiled;

import lombok.Data;

/**
 * to load the properties form exporter.properties
 */
@Data
@Config(prefix = "eventmesh.trace", path = "classPath://exporter.properties")
public class ExporterConfiguration {

    @ConfigFiled(field = "max.export.size")
    private int eventMeshTraceMaxExportSize = 512;

    @ConfigFiled(field = "max.queue.size")
    private int eventMeshTraceMaxQueueSize = 2048;

    @ConfigFiled(field = "export.timeout")
    private int eventMeshTraceExportTimeout = 30;

    @ConfigFiled(field = "export.interval")
    private int eventMeshTraceExportInterval = 5;
}

==> apache-eventmesh-1.12.0-source.tar.gz: apache-eventmesh-1.12.0-src/eventmesh-trace-plugin/eventmesh-trace-api/src/main/java/org/apache/eventmesh/trace/api/config/ExporterConfiguration.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.eventmesh.trace.api.config;

import org.apache.eventmesh.common.config.Config;
import org.apache.eventmesh.common.config.ConfigField;

import lombok.Data;

/**
 * to load the properties form exporter.properties
 */
@Data
@Config(prefix = "eventmesh.trace", path = "classPath://exporter.properties")
public class ExporterConfiguration {

    @ConfigField(field = "max.export.size")
    private int eventMeshTraceMaxExportSize = 512;

    @ConfigField(field = "max.queue.size")
    private int eventMeshTraceMaxQueueSize = 2048;

    @ConfigField(field = "export.timeout")
    private int eventMeshTraceExportTimeout = 30;

    @ConfigField(field = "export.interval")
    private int eventMeshTraceExportInterval = 5;
}
